@@ -84,6 +84,9 @@ class SimpleIndexTestCase(IndexTestCase):
     def test_iter(self) -> None:
         self.assertEqual([b"bla"], list(self.get_simple_index("index")))
 
+    def test_iter_skip_hash(self) -> None:
+        self.assertEqual([b"bla"], list(self.get_simple_index("index_skip_hash")))
+
     def test_iterobjects(self) -> None:
         self.assertEqual(
             [(b"bla", b"e69de29bb2d1d6434b8b29ae775ad8c2e48c5391", 33188)],
@@ -102,6 +105,8 @@ class SimpleIndexTestCase(IndexTestCase):
                 1000,
                 0,
                 b"e69de29bb2d1d6434b8b29ae775ad8c2e48c5391",
+                0,
+                0,
             ),
             self.get_simple_index("index")[b"bla"],
         )
@@ -177,6 +182,8 @@ class ReadIndexDictTests(IndexTestCase):
                 1000,
                 0,
                 b"e69de29bb2d1d6434b8b29ae775ad8c2e48c5391",
+                0,
+                0,
             )
         }
         filename = os.path.join(self.tempdir, "test-simple-write-index")
@@ -287,6 +294,8 @@ class IndexEntryFromStatTests(TestCase):
                 1000,
                 12288,
                 b"2222222222222222222222222222222222222222",
+                0,
+                0,
             ),
         )
 
@@ -318,6 +327,8 @@ class IndexEntryFromStatTests(TestCase):
                 1000,
                 12288,
                 b"2222222222222222222222222222222222222222",
+                0,
+                0,
             ),
         )
 
